==> haskell-decimal-0.5.2-128-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-decimal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Decimal
version:              0.5.2
visibility:           public
id:                   Decimal-0.5.2-FZVdXLcePM2H7jSypcEkWe
key:                  Decimal-0.5.2-FZVdXLcePM2H7jSypcEkWe
license:              BSD-3-Clause
copyright:            Paul Johnson, 2013, 2018, 2021.
maintainer:           paul@cogito.org.uk
author:               Paul Johnson
stability:            beta
homepage:             https://github.com/PaulJohnson/Haskell-Decimal
synopsis:             Decimal numbers with variable precision
description:
    A decimal number has an integer mantissa and a negative
    exponent.  The exponent can be interpreted as the number
    of decimal places in the value.

category:             Math
abi:                  33501a3dc0619bd348ba57f9bdd59597
exposed:              True
exposed-modules:      Data.Decimal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/Decimal-0.5.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/Decimal-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-decimal
hs-libraries:         HSDecimal-0.5.2-FZVdXLcePM2H7jSypcEkWe
depends:              base-4.16.4.0 deepseq-1.4.6.1
haddock-interfaces:   /usr/share/doc/haskell-decimal/html/Decimal.haddock
haddock-html:         /usr/share/doc/haskell-decimal/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-decimal-0.5.2-156.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-decimal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Decimal
version:              0.5.2
visibility:           public
id:                   Decimal-0.5.2-3BWzXZ8Sog3BaamV4VU2uf
key:                  Decimal-0.5.2-3BWzXZ8Sog3BaamV4VU2uf
license:              BSD-3-Clause
copyright:            Paul Johnson, 2013, 2018, 2021.
maintainer:           paul@cogito.org.uk
author:               Paul Johnson
stability:            beta
homepage:             https://github.com/PaulJohnson/Haskell-Decimal
synopsis:             Decimal numbers with variable precision
description:
    A decimal number has an integer mantissa and a negative
    exponent.  The exponent can be interpreted as the number
    of decimal places in the value.

category:             Math
abi:                  9e5c24a6d706422bbc26f023486df2a5
exposed:              True
exposed-modules:      Data.Decimal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/Decimal-0.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/Decimal-0.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/Decimal-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-decimal
hs-libraries:         HSDecimal-0.5.2-3BWzXZ8Sog3BaamV4VU2uf
depends:              base-4.17.2.1 deepseq-1.4.8.0
haddock-interfaces:   /usr/share/doc/haskell-decimal/html/Decimal.haddock
haddock-html:         /usr/share/doc/haskell-decimal/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
